@@ -6,15 +6,18 @@
  * for the browser to set which one is currently being used.
  *
  * Detects which user environment WordPress is being used on.
- * Only attempts to check for Apache and IIS. Two web servers
- * with known permalink capability.
+ * Only attempts to check for Apache, Nginx and IIS -- three web
+ * servers with known pretty permalink capability.
+ *
+ * Note: Though Nginx is detected, WordPress does not currently
+ * generate rewrite rules for it. See https://codex.wordpress.org/Nginx
  *
  * @package WordPress
  */
 
 global $pagenow,
 	$is_lynx, $is_gecko, $is_winIE, $is_macIE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone, $is_IE,
-	$is_apache, $is_IIS, $is_iis7;
+	$is_apache, $is_IIS, $is_iis7, $is_nginx;
 
 // On which page are we ?
 if ( is_admin() ) {
@@ -52,7 +55,15 @@ if ( isset($_SERVER['HTTP_USER_AGENT']) ) {
 		$is_lynx = true;
 	} elseif ( stripos($_SERVER['HTTP_USER_AGENT'], 'chrome') !== false ) {
 		if ( stripos( $_SERVER['HTTP_USER_AGENT'], 'chromeframe' ) !== false ) {
-			if ( $is_chrome = apply_filters( 'use_google_chrome_frame', is_admin() ) )
+			$is_admin = is_admin();
+			/**
+			 * Filter whether Google Chrome Frame should be used, if available.
+			 *
+			 * @since 3.2.0
+			 *
+			 * @param bool $is_admin Whether to use the Google Chrome Frame. Default is the value of is_admin().
+			 */
+			if ( $is_chrome = apply_filters( 'use_google_chrome_frame', $is_admin ) )
 				header( 'X-UA-Compatible: chrome=1' );
 			$is_winIE = ! $is_chrome;
 		} else {
@@ -60,12 +71,12 @@ if ( isset($_SERVER['HTTP_USER_AGENT']) ) {
 		}
 	} elseif ( stripos($_SERVER['HTTP_USER_AGENT'], 'safari') !== false ) {
 		$is_safari = true;
-	} elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'Gecko') !== false ) {
-		$is_gecko = true;
-	} elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false && strpos($_SERVER['HTTP_USER_AGENT'], 'Win') !== false ) {
+	} elseif ( ( strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false || strpos($_SERVER['HTTP_USER_AGENT'], 'Trident') !== false ) && strpos($_SERVER['HTTP_USER_AGENT'], 'Win') !== false ) {
 		$is_winIE = true;
 	} elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false && strpos($_SERVER['HTTP_USER_AGENT'], 'Mac') !== false ) {
 		$is_macIE = true;
+	} elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'Gecko') !== false ) {
+		$is_gecko = true;
 	} elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'Opera') !== false ) {
 		$is_opera = true;
 	} elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'Nav') !== false && strpos($_SERVER['HTTP_USER_AGENT'], 'Mozilla/4.') !== false ) {
@@ -86,6 +97,12 @@ $is_IE = ( $is_macIE || $is_winIE );
  */
 $is_apache = (strpos($_SERVER['SERVER_SOFTWARE'], 'Apache') !== false || strpos($_SERVER['SERVER_SOFTWARE'], 'LiteSpeed') !== false);
 
+/**
+ * Whether the server software is Nginx or something else
+ * @global bool $is_nginx
+ */
+$is_nginx = (strpos($_SERVER['SERVER_SOFTWARE'], 'nginx') !== false);
+
 /**
  * Whether the server software is IIS or something else
  * @global bool $is_IIS
@@ -101,13 +118,16 @@ $is_iis7 = $is_IIS && intval( substr( $_SERVER['SERVER_SOFTWARE'], strpos( $_SER
 /**
  * Test if the current browser runs on a mobile device (smart phone, tablet, etc.)
  *
- * @return bool true|false
+ * @staticvar bool $is_mobile
+ *
+ * @return bool
  */
 function wp_is_mobile() {
-	static $is_mobile;
+	static $is_mobile = null;
 
-	if ( isset($is_mobile) )
+	if ( isset( $is_mobile ) ) {
 		return $is_mobile;
+	}
 
 	if ( empty($_SERVER['HTTP_USER_AGENT']) ) {
 		$is_mobile = false;
